@@ -208,8 +208,6 @@ class YubikeyVal(App):
 
     YubiKey OTP validation server
     """
-
-    name = 'val'
     sections = ['general', 'clients', 'database', 'synchronization', 'ksms',
                 'advanced']
 
@@ -221,9 +219,6 @@ class YubikeyVal(App):
         self._clients = YubikeyValClients()
 
     def general(self, request):
-        """
-        General
-        """
         return self.render_forms(request, [SyncLevelsForm(), MiscForm()])
 
     def clients(self, request):
@@ -241,9 +236,6 @@ class YubikeyVal(App):
         return self.render_forms(request, [dbform])
 
     def synchronization(self, request):
-        """
-        Synchronization
-        """
         return self.render_forms(request, [DaemonForm(), SyncPoolForm()],
                                  template='val/synchronization',
                                  daemon_running=is_daemon_running())
@@ -266,9 +258,6 @@ class YubikeyVal(App):
         return self.render_forms(request, [KSMForm()])
 
     def advanced(self, request):
-        """
-        Advanced
-        """
         return self.render_forms(request, [
             FileForm(YKVAL_CONFIG_FILE, 'Configuration', lang='php')
         ], script='editor')
